@@ -8,7 +8,8 @@ from xmlApiParse.enums import SpecificCollectionsEnum, AllCollectionsEnum
 from xmlApiParse.repository import (
     ParseError, ConnectionErrors, BadRequestError,
     WaiterListDTO, OrderListDTO, RestaurantsDTO,
-    MenuDTO, MenuItemsDTO, EmployeeDTO, WaiterDTO
+    MenuDTO, MenuItemsDTO, EmployeeDTO, WaiterDTO,
+    GetOrderDTO, GetVisitDTO
 )
 
 
@@ -58,6 +59,14 @@ class XMLRequest(ABC):
     def category(self):
         pass
 
+    @abstractclassmethod
+    def get_order(self):
+        pass
+
+    @abstractclassmethod
+    def get_visits(self):
+        pass
+
 
 class RKXMLRequest(XMLRequest):
     media_type = "text/xml"
@@ -214,7 +223,7 @@ class RKXMLRequest(XMLRequest):
                     order_id=(order.get('OrderID')), count_guest=(visit.get('GuestsCount')),
                     order_name=(order.get('OrderName')), url=(order.get('Url')),
                     version=(order.get('Version')), crc32=(order.get('Crc32')),
-                    guid=(order.get('Guid')), table_id=(order.get('TableID')),
+                    guid=(order.get('guid')), table_id=(order.get('TableID')),
                     table_code=(order.get('TableCode')), order_categ_id=(order.get('OrderCategId')),
                     order_categ_code=(order.get('OrderCategCode')), bill=(order.get('Bill')),
                     waiter_id=(order.get('WaiterID')), order_type_code=(order.get('OrderTypeCode')),
@@ -357,3 +366,42 @@ class RKXMLRequest(XMLRequest):
         except Exception as error:
             raise ParseError(f"XML parse error - {str(error)}")
         return element
+
+    def get_visits(self):
+        body = '<RK7Query><RK7CMD CMD="GetOrderList"/></RK7Query>'
+        response = self.send_request(body=body)
+        element_list = []
+        guid = []
+        try:
+            parsed_element = Etree.fromstring(response.content)
+            for item in parsed_element.findall("./Visit"):
+                if item[0].tag == "Guests":
+                    order = item[1][0].attrib
+                    order_dto = GetVisitDTO(
+                    order_id=(order.get('OrderID')), guid=(order.get('guid')))
+                    guid.append(order.get('guid'))
+                    element_list.append(order_dto)
+        except (ParseError, ValueError) as error:
+            raise ParseError(f"XML parse error - {str(error)}")
+        return guid
+
+    def get_order(self) -> List[GetOrderDTO]:
+        element_list = []
+        for guid in self.get_visits():
+            body = f'<RK7Query><RK7Command CMD="GetOrder"><Order guid="{guid}"/></RK7Command></RK7Query>'
+            response = self.send_request(body=body)
+            file = open('data.txt', 'a')
+            file.write(str(response.text))
+            parsed_collection = Etree.fromstring(response.content)
+            for order in parsed_collection.findall('./CommandResult/Order'):
+                order_item = order.attrib
+                for dish in order.findall('./Session/Dish'):
+                    attr_of_item_node = dish.attrib
+                    order_obj = {
+                        'order_guid': order_item.get('guid'),
+                        'id': attr_of_item_node.get('id'),
+                        'name': attr_of_item_node.get('name'),
+                        'quantity': int(attr_of_item_node.get('quantity')) / 1000
+                    }
+                    element_list.append(order_obj)
+        return element_list
